@@ -569,7 +569,10 @@ def hold(doc: Document | None = None, policy: HoldPolicyType = 'combine', comm:
             if comm is not None:
                 from .notebook import push
                 push(doc, comm)
-            doc.unhold()
+            if state._loaded.get(doc):
+                doc.unhold()
+            else:
+                doc.callbacks._hold = None
 
 @contextmanager
 def immediate_dispatch(doc: Document | None = None):
