@@ -313,6 +313,8 @@ def serve_and_wait(app, page=None, prefix=None, port=None, proxy=None, **kwargs)
     else:
         port = server.port
     wait_for_server(port, prefix=prefix)
+    if page:
+        page.wait_for_function("document.readyState === 'complete'", timeout=5000)
     return port
 
 serve_and_wait.server_implementation = 'tornado'
@@ -321,11 +323,13 @@ def serve_component(page, app, suffix='', wait=True, **kwargs):
     msgs = []
     page.on("console", lambda msg: msgs.append(msg))
     port = serve_and_wait(app, page, **kwargs)
-    page.goto(f"http://localhost:{port}{suffix}")
+    page.goto(f"http://localhost:{port}{suffix}", wait_until="domcontentloaded")
 
     if wait:
         wait_until(lambda: any("Websocket connection 0 is now open" in str(msg) for msg in msgs), page, interval=10)
 
+    if page and wait:
+        page.wait_for_function("document.readyState === 'complete'", timeout=5000)
     return msgs, port
 
 
