@@ -20,3 +20,7 @@ class TestToggleIcon:
     def test_empty_icon(self):
         with pytest.raises(ValueError, match="The icon parameter must not "):
             ToggleIcon(icon="")
+
+    def test_icon_svg_empty_active_icon(self):
+        with pytest.raises(ValueError, match="The active_icon parameter must not "):
+            ToggleIcon(icon="<svg></svg>")
